<!-- Please disclose any use of LLMs (ChatGPT, Copilot, Gemini, etc.) during the preparation of this PR. -->

<!-- The following text must be left intact and the box checked before the PR can be merged. -->

- [ ] By submitting this pull request, I assign the copyright of my contribution to _The igraph development team_.
